#!/bin/bash
#
# Copyright 2013 Stefan Brenner, Sven Schober
#
# This file is part of DAE.
#
# DAE is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# DAE is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DAE.  If not, see <http://www.gnu.org/licenses/>.
#

if [ $# -ge 10 ]; then

	OUT_DIR="fig"
	mkdir -p $OUT_DIR 
	OUT_FILE=$1
	XLABEL=$2
	YLABEL=$3
	XS=$4
	XE=$5
	YS=$6
	YE=$7
	LOG=""
	if [ $8 -eq "1" ]; then
		LOG="set logscale y"
	fi
	ROWS="1:2"
	if [ $9 -eq "1" ]; then
		ROWS="2:1"
	fi

	# format:
	# plot <infile> using row:row title <title> with lines ls <ls>, ...
	# plot filename.dat using 1:2 title MyTitle with lines ls 1, ...
	PLT1="'${11}' using $ROWS title '${10}' with lp ls 1 "
	if [ $# -ge 13 ]; then
		PLT2="'${13}' using $ROWS title '${12}' with lp ls 2, "
		if [ $# -ge 15 ]; then
			PLT3="'${15}' using $ROWS title '${14}' with lp ls 3, "
			if [ $# -ge 17 ]; then
				PLT4="'${17}' using $ROWS title '${16}' with lines ls 4, "
			fi
		fi
	fi
	PLTS="$PLT4 $PLT3 $PLT2 $PLT1"

	gnuplot -persist <<PLOT
	set term epslatex size 10cm,7cm color colortext #standalone
	set output "$OUT_DIR/$OUT_FILE"
	set datafile separator ";"
	set xlabel "$XLABEL"
	set ylabel "$YLABEL"
	set xrange[$XS:$XE]
	set yrange[$YS:$YE]
        set key bottom right
	$LOG
	set linestyle 1 lt 5 lc 0 pi 2 pt 4
	set linestyle 2 lt 3 lc 0 pi 2
	set linestyle 3 lt 1 lc 0 pi 2
	plot $PLTS
PLOT

else 
	echo "usage $0 <outfile> <xlbl> <ylbl> <xstart> <xend> <ystart> <yend> <logarithmic> <flip> <desc1> <plotfile1> [<desc2> <plotfile2> [<desc3> <plotfile3> [<desc4> <plotfile4>]]]"

fi
