#!/bin/bash
#
# Copyright 2013 Stefan Brenner, Sven Schober
#
# This file is part of DAE.
#
# DAE is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# DAE is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DAE.  If not, see <http://www.gnu.org/licenses/>.
#

### global config
DIR="./results"
EXE="./master.sh"
PLOT="./gnuplot.sh"
DEF_ITER=10
CALC=0

mkdir -p $DIR

### execution

# numbers 0.0 0.1 ... 1.0
num=$(awk 'BEGIN{for(i=0;i<=1;i+=0.1)print i}' | sed 's/,/./')

# measurements planetlab

sequoia="$DIR/planetlab-measurements-sequoia.dat"
song="$DIR/planetlab-measurements-song.dat"
dae="$DIR/planetlab-measurements-dae.dat"
table="planetlab-measurements.tex"

rm $sequoia
rm $song
rm $dae

touch $sequoia
touch $song
touch $dae

$EXE -to planetlab -tr sequoia -avgmeas -std -i $DEF_ITER >> $sequoia
$EXE -to planetlab -tr song    -avgmeas -std -i $DEF_ITER >> $song
$EXE -to planetlab -tr dae     -avgmeas -std -i $DEF_ITER >> $dae

# measurements synthetic

sequoia="$DIR/synthetic-measurements-sequoia.dat"
song="$DIR/synthetic-measurements-song.dat"
dae="$DIR/synthetic-measurements-dae.dat"
table="synthetic-measurements.tex"

rm $sequoia
rm $song
rm $dae

touch $sequoia
touch $song
touch $dae

$EXE -to dslconnections -tr sequoia -avgmeas -std -i $DEF_ITER >> $sequoia
$EXE -to dslconnections -tr song    -avgmeas -std -i $DEF_ITER >> $song
$EXE -to dslconnections -tr dae     -avgmeas -std -i $DEF_ITER >> $dae

FILES=`find $DIR -name '*meas*' | sort -r`
echo "Ordering: "
echo "$FILES"
cat $FILES | grep -v "Tree"
