/**
 *
 * Copyright 2013 Stefan Brenner, Sven Schober
 *
 * This file is part of DAE.
 *
 * DAE is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * DAE is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DAE.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package sequoia.topology;

import java.io.BufferedReader;
import java.io.FileReader;

import sequoia.Master;

/**
 * Perfect topology, with perfect treeness, that is, all epsilon values
 * (4PC-epsilon) are 0
 * 
 * @author stefan
 * 
 */
public class TopPerfectTreeness extends Topology {

	// constant to scale bandwidth values up
	private static double SCALE = Master.CONST / 100;

	/**
	 * Default constructor
	 */
	public TopPerfectTreeness() {
		setDescription("Topology with perfect treeness (4pc-e = 0) created by reading link weights of an existing tree.");

		try {
			// read complete file
			BufferedReader br = new BufferedReader(new FileReader("data/perfect-treeness4.txt"));
			String linebuffer;
			while ((linebuffer = br.readLine()) != null) {

				// skip comments
				linebuffer = linebuffer.trim();
				if (linebuffer.startsWith("#"))
					continue;

				// parse line
				String[] parts = linebuffer.split(" ");
				if (parts.length < 3)
					continue;

				// select column which contains bandwidth measurement
				String hostname_a = parts[0];
				String hostname_b = parts[1];

				/**
				 * Values parsed from the files are distance values on a tree
				 * for convention. So they have to be converted to represent
				 * bandwidth values, with inverse characteristic by substracting
				 * them from a high constant. While Sequoia and Song use
				 * different transform functions it is not neccessary to decide
				 * here which system will embed the tree as the topology just
				 * provides some bandwidth values no matter how they are
				 * produced.
				 */

				String bandwidth_value = parts[2];
				double abw = Double.parseDouble(bandwidth_value);
				int intBw = (int) (Master.CONST - SCALE * Math.round(abw));
				// int intBw = (int) (abw * SCALE);

				// store new hostnames
				rememberHostname(hostname_a);
				rememberHostname(hostname_b);

				// store value symmetric(!): same value for both link directions
				addLinkBandwidth(hostname_a, hostname_b, intBw);
				addLinkBandwidth(hostname_b, hostname_a, intBw);

			}
			br.close();

			shuffle();

		} catch (Exception e) {
			e.printStackTrace();
		}

	}

}
